#include "test1.h"

int main( int, char ** )
{
  Test1 t( QString(), QString() );
}
